.. complexity documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents:
=========

.. toctree::
   :maxdepth: 2

   installation
   usage
   galight
   contributing
   authors
   history

Feedback
========

If you have any suggestions or questions about using ``galight`` feel free to email me
at xuheng.ding@ipmu.jp.

If you encounter any errors or problems with ``galight``, please let me know!
Open an Issue at the GitHub http://github.com/dartoon/galight main repository.


Citation
========
.. code-block:: bash

   @ARTICLE{2020ApJ...888...37D,
   author = {{Ding}, Xuheng and {Silverman}, John and {Treu}, Tommaso and {Schulze}, Andreas and {Schramm}, Malte and {Birrer}, Simon and {Park}, Daeseong and {Jahnke}, Knud and {Bennert}, Vardha N. and {Kartaltepe}, Jeyhan S. and {Koekemoer}, Anton M. and {Malkan}, Matthew A. and {Sanders}, David},
   title = "{The Mass Relations between Supermassive Black Holes and Their Host Galaxies at 1 < z < 2 HST-WFC3}",
   journal = {\apj},
   keywords = {Galaxy evolution, Active galaxies, 594, 17, Astrophysics - Astrophysics of Galaxies},
   year = 2020,
   month = jan,
   volume = {888},
   number = {1},
   eid = {37},
   pages = {37},
   doi = {10.3847/1538-4357/ab5b90},
   archivePrefix = {arXiv},
   eprint = {1910.11875},
   primaryClass = {astro-ph.GA},
   adsurl = {https://ui.adsabs.harvard.edu/abs/2020ApJ...888...37D},
   adsnote = {Provided by the SAO/NASA Astrophysics Data System}
   }
